==> zio-aws-personalizeevents_3-5.17.125.1-sources.jar: zio/aws/personalizeevents/model/Event.scala <==
package zio.aws.personalizeevents.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import zio.aws.personalizeevents.model.primitives.{
  FloatType,
  Date,
  EventPropertiesJSON,
  ItemId,
  RecommendationId,
  StringType
}
import scala.jdk.CollectionConverters.*
final case class Event(
    eventId: Option[StringType] = None,
    eventType: StringType,
    eventValue: Option[FloatType] = None,
    itemId: Option[ItemId] = None,
    properties: Option[EventPropertiesJSON] = None,
    sentAt: Date,
    recommendationId: Option[RecommendationId] = None,
    impression: Option[Iterable[ItemId]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.personalizeevents.model.Event = {
    import Event.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.personalizeevents.model.Event
      .builder()
      .optionallyWith(
        eventId.map(value => StringType.unwrap(value): java.lang.String)
      )(_.eventId)
      .eventType(StringType.unwrap(eventType): java.lang.String)
      .optionallyWith(
        eventValue.map(value => FloatType.unwrap(value): java.lang.Float)
      )(_.eventValue)
      .optionallyWith(
        itemId.map(value => ItemId.unwrap(value): java.lang.String)
      )(_.itemId)
      .optionallyWith(
        properties.map(value =>
          EventPropertiesJSON.unwrap(value): java.lang.String
        )
      )(_.properties)
      .sentAt(Date.unwrap(sentAt): Instant)
      .optionallyWith(
        recommendationId.map(value =>
          RecommendationId.unwrap(value): java.lang.String
        )
      )(_.recommendationId)
      .optionallyWith(
        impression.map(value =>
          value.map { item =>
            ItemId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.impression)
      .build()
  }
  def asReadOnly: zio.aws.personalizeevents.model.Event.ReadOnly =
    zio.aws.personalizeevents.model.Event.wrap(buildAwsValue())
}
object Event {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.personalizeevents.model.Event
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.personalizeevents.model.Event =
      zio.aws.personalizeevents.model.Event(
        eventId.map(value => value),
        eventType,
        eventValue.map(value => value),
        itemId.map(value => value),
        properties.map(value => value),
        sentAt,
        recommendationId.map(value => value),
        impression.map(value => value)
      )
    def eventId: Option[StringType]
    def eventType: StringType
    def eventValue: Option[FloatType]
    def itemId: Option[ItemId]
    def properties: Option[EventPropertiesJSON]
    def sentAt: Date
    def recommendationId: Option[RecommendationId]
    def impression: Option[List[ItemId]]
    def getEventId: ZIO[Any, AwsError, StringType] =
      AwsError.unwrapOptionField("eventId", eventId)
    def getEventType: ZIO[Any, Nothing, StringType] = ZIO.succeed(eventType)
    def getEventValue: ZIO[Any, AwsError, FloatType] =
      AwsError.unwrapOptionField("eventValue", eventValue)
    def getItemId: ZIO[Any, AwsError, ItemId] =
      AwsError.unwrapOptionField("itemId", itemId)
    def getProperties: ZIO[Any, AwsError, EventPropertiesJSON] =
      AwsError.unwrapOptionField("properties", properties)
    def getSentAt: ZIO[Any, Nothing, Date] = ZIO.succeed(sentAt)
    def getRecommendationId: ZIO[Any, AwsError, RecommendationId] =
      AwsError.unwrapOptionField("recommendationId", recommendationId)
    def getImpression: ZIO[Any, AwsError, List[ItemId]] =
      AwsError.unwrapOptionField("impression", impression)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.personalizeevents.model.Event
  ) extends zio.aws.personalizeevents.model.Event.ReadOnly {
    override val eventId: Option[StringType] = scala
      .Option(impl.eventId())
      .map(value =>
        zio.aws.personalizeevents.model.primitives.StringType(value)
      )
    override val eventType: StringType =
      zio.aws.personalizeevents.model.primitives.StringType(impl.eventType())
    override val eventValue: Option[FloatType] = scala
      .Option(impl.eventValue())
      .map(value => zio.aws.personalizeevents.model.primitives.FloatType(value))
    override val itemId: Option[ItemId] = scala
      .Option(impl.itemId())
      .map(value => zio.aws.personalizeevents.model.primitives.ItemId(value))
    override val properties: Option[EventPropertiesJSON] = scala
      .Option(impl.properties())
      .map(value =>
        zio.aws.personalizeevents.model.primitives.EventPropertiesJSON(value)
      )
    override val sentAt: Date =
      zio.aws.personalizeevents.model.primitives.Date(impl.sentAt())
    override val recommendationId: Option[RecommendationId] = scala
      .Option(impl.recommendationId())
      .map(value =>
        zio.aws.personalizeevents.model.primitives.RecommendationId(value)
      )
    override val impression: Option[List[ItemId]] = scala
      .Option(impl.impression())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.personalizeevents.model.primitives.ItemId(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.personalizeevents.model.Event
  ): zio.aws.personalizeevents.model.Event.ReadOnly = new Wrapper(impl)
}

==> zio-aws-personalizeevents_3-5.17.155.2-sources.jar: zio/aws/personalizeevents/model/Event.scala <==
package zio.aws.personalizeevents.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import zio.aws.personalizeevents.model.primitives.{
  FloatType,
  Date,
  EventPropertiesJSON,
  ItemId,
  RecommendationId,
  StringType
}
import scala.jdk.CollectionConverters.*
final case class Event(
    eventId: Option[StringType] = None,
    eventType: StringType,
    eventValue: Option[FloatType] = None,
    itemId: Option[ItemId] = None,
    properties: Option[EventPropertiesJSON] = None,
    sentAt: Date,
    recommendationId: Option[RecommendationId] = None,
    impression: Option[Iterable[ItemId]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.personalizeevents.model.Event = {
    import Event.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.personalizeevents.model.Event
      .builder()
      .optionallyWith(eventId.map(value => value: java.lang.String))(_.eventId)
      .eventType(eventType: java.lang.String)
      .optionallyWith(
        eventValue.map(value => FloatType.unwrap(value): java.lang.Float)
      )(_.eventValue)
      .optionallyWith(
        itemId.map(value => ItemId.unwrap(value): java.lang.String)
      )(_.itemId)
      .optionallyWith(
        properties.map(value =>
          EventPropertiesJSON.unwrap(value): java.lang.String
        )
      )(_.properties)
      .sentAt(Date.unwrap(sentAt): Instant)
      .optionallyWith(
        recommendationId.map(value =>
          RecommendationId.unwrap(value): java.lang.String
        )
      )(_.recommendationId)
      .optionallyWith(
        impression.map(value =>
          value.map { item =>
            ItemId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.impression)
      .build()
  }
  def asReadOnly: zio.aws.personalizeevents.model.Event.ReadOnly =
    zio.aws.personalizeevents.model.Event.wrap(buildAwsValue())
}
object Event {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.personalizeevents.model.Event
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.personalizeevents.model.Event =
      zio.aws.personalizeevents.model.Event(
        eventId.map(value => value),
        eventType,
        eventValue.map(value => value),
        itemId.map(value => value),
        properties.map(value => value),
        sentAt,
        recommendationId.map(value => value),
        impression.map(value => value)
      )
    def eventId: Option[StringType]
    def eventType: StringType
    def eventValue: Option[FloatType]
    def itemId: Option[ItemId]
    def properties: Option[EventPropertiesJSON]
    def sentAt: Date
    def recommendationId: Option[RecommendationId]
    def impression: Option[List[ItemId]]
    def getEventId: ZIO[Any, AwsError, StringType] =
      AwsError.unwrapOptionField("eventId", eventId)
    def getEventType: ZIO[Any, Nothing, StringType] = ZIO.succeed(eventType)
    def getEventValue: ZIO[Any, AwsError, FloatType] =
      AwsError.unwrapOptionField("eventValue", eventValue)
    def getItemId: ZIO[Any, AwsError, ItemId] =
      AwsError.unwrapOptionField("itemId", itemId)
    def getProperties: ZIO[Any, AwsError, EventPropertiesJSON] =
      AwsError.unwrapOptionField("properties", properties)
    def getSentAt: ZIO[Any, Nothing, Date] = ZIO.succeed(sentAt)
    def getRecommendationId: ZIO[Any, AwsError, RecommendationId] =
      AwsError.unwrapOptionField("recommendationId", recommendationId)
    def getImpression: ZIO[Any, AwsError, List[ItemId]] =
      AwsError.unwrapOptionField("impression", impression)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.personalizeevents.model.Event
  ) extends zio.aws.personalizeevents.model.Event.ReadOnly {
    override val eventId: Option[StringType] =
      scala.Option(impl.eventId()).map(value => value: StringType)
    override val eventType: StringType = impl.eventType(): StringType
    override val eventValue: Option[FloatType] = scala
      .Option(impl.eventValue())
      .map(value => zio.aws.personalizeevents.model.primitives.FloatType(value))
    override val itemId: Option[ItemId] = scala
      .Option(impl.itemId())
      .map(value => zio.aws.personalizeevents.model.primitives.ItemId(value))
    override val properties: Option[EventPropertiesJSON] = scala
      .Option(impl.properties())
      .map(value =>
        zio.aws.personalizeevents.model.primitives.EventPropertiesJSON(value)
      )
    override val sentAt: Date =
      zio.aws.personalizeevents.model.primitives.Date(impl.sentAt())
    override val recommendationId: Option[RecommendationId] = scala
      .Option(impl.recommendationId())
      .map(value =>
        zio.aws.personalizeevents.model.primitives.RecommendationId(value)
      )
    override val impression: Option[List[ItemId]] = scala
      .Option(impl.impression())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.personalizeevents.model.primitives.ItemId(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.personalizeevents.model.Event
  ): zio.aws.personalizeevents.model.Event.ReadOnly = new Wrapper(impl)
}
